Move more globals into the game state block.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index e0a5be1e822eb8638b61c43b4c713492166cb0fc..bee722d504f4e3052c72c2825e233da35b639eb1 100644 (file)
--- a/score.c
+++ b/score.c
@@ -1,7 +1,6 @@
 #include <stdlib.h>
-#include "misc.h"
-#include "main.h"
-#include "share.h"
+#include "advent.h"
+#include "database.h"
 
 /*
  * scoring and wrap-up
@@ -18,7 +17,7 @@ void score(long MODE) {
  *  Each treasure > chest    16                   224
  *  Surviving             (MAX-NUM)*10             30
  *  Not quitting              4                     4
- *  Reaching "CLOSNG"        25                    25
+ *  Reaching "game.closng"        25                    25
  *  "Closed": Quit/Killed    10
  *            Klutzed        25
  *            Wrong way      30
@@ -29,10 +28,10 @@ void score(long MODE) {
  *  Points can also be deducted for using hints or too many turns, or for
  *  saving intermediate positions. */
 
-L20000: SCORE=0;
+       SCORE=0;
        MXSCOR=0;
 
-/*  First tally up the treasures.  must be in building and not broken.
+/*  First tally up the treasures.  Must be in building and not broken.
  *  Give the poor guy 2 points just for finding each treasure. */
 
        /* 20010 */ for (I=50; I<=MAXTRS; I++) {
@@ -47,25 +46,25 @@ L20010: /*etc*/ ;
        } /* end loop */
 
 /*  Now look at how he finished and how far he got.  MAXDIE and NUMDIE tell us
*  how well he survived.  DFLAG will
*  tell us if he ever got suitably deep into the cave.  CLOSNG still indicates
  *  whether he reached the endgame.  And if he got as far as "cave closed"
*  (indicated by "CLOSED"), then bonus is zero for mundane exits or 133, 134,
  *  135 if he blew it (so to speak). */
 
        SCORE=SCORE+(MAXDIE-NUMDIE)*10;
        MXSCOR=MXSCOR+MAXDIE*10;
        if(MODE == 0)SCORE=SCORE+4;
        MXSCOR=MXSCOR+4;
-       if(DFLAG != 0)SCORE=SCORE+25;
+       if(game.dflag != 0)SCORE=SCORE+25;
        MXSCOR=MXSCOR+25;
-       if(CLOSNG)SCORE=SCORE+25;
+       if(game.closng)SCORE=SCORE+25;
        MXSCOR=MXSCOR+25;
-       if(!CLOSED) goto L20020;
-       if(BONUS == 0)SCORE=SCORE+10;
-       if(BONUS == 135)SCORE=SCORE+25;
-       if(BONUS == 134)SCORE=SCORE+30;
-       if(BONUS == 133)SCORE=SCORE+45;
+       if(!game.closed) goto L20020;
+       if(game.bonus == 0)SCORE=SCORE+10;
+       if(game.bonus == 135)SCORE=SCORE+25;
+       if(game.bonus == 134)SCORE=SCORE+30;
+       if(game.bonus == 133)SCORE=SCORE+45;
 L20020: MXSCOR=MXSCOR+45;
 
 /*  Did he come to Witt's End as he should? */
@@ -80,8 +79,8 @@ L20020: MXSCOR=MXSCOR+45;
 
 /*  Deduct for hints/turns/saves.  Hints < 4 are special; see database desc. */
 
-       /* 20030 */ for (I=1; I<=HNTMAX; I++) {
-L20030: if(HINTED[I])SCORE=SCORE-HINTS[I][2];
+       for (I=1; I<=HNTMAX; I++) {
+       if(HINTED[I])SCORE=SCORE-HINTS[I][2];
        } /* end loop */
        if(NOVICE)SCORE=SCORE-5;
        if(CLSHNT)SCORE=SCORE-10;
@@ -98,9 +97,9 @@ L20030: if(HINTED[I])SCORE=SCORE-HINTS[I][2];
        SETPRM(1,SCORE,MXSCOR);
        SETPRM(3,TURNS,TURNS);
        RSPEAK(262);
-       /* 20200 */ for (I=1; I<=CLSSES; I++) {
+       for (I=1; I<=CLSSES; I++) {
        if(CVAL[I] >= SCORE) goto L20210;
-L20200: /*etc*/ ;
+       /*etc*/ ;
        } /* end loop */
        SPK=265;
         goto L25000;
@@ -47,25 +46,25 @@ L20010: /*etc*/ ;
 
 /*  Now look at how he finished and how far he got.  MAXDIE and NUMDIE tell us
- *  how well he survived.  DFLAG will
- *  tell us if he ever got suitably deep into the cave.  CLOSNG still indicates
+ *  how well he survived.  game.dflag will
+ *  tell us if he ever got suitably deep into the cave.  game.closng still indicates
  *  whether he reached the endgame.  And if he got as far as "cave closed"
@@ -47,25 +46,25 @@ L20010: /*etc*/ ;
  *  whether he reached the endgame.  And if he got as far as "cave closed"
- *  (indicated by "CLOSED"), then bonus is zero for mundane exits or 133, 134,
+ *  (indicated by "game.closed"), then bonus is zero for mundane exits or 133, 134,
  *  135 if he blew it (so to speak). */
 